@@ -40,7 +40,11 @@ import Data.List.NonEmpty (NonEmpty((:|)), (<|), toList)
 import Data.Semigroup
 #endif
 
-newtype ContextStack = ContextStack{ unContextStack :: NonEmpty Context }
+newtype Captures = Captures{ unCaptures :: IntMap.IntMap ByteString }
+  deriving (Show)
+
+newtype ContextStack =
+  ContextStack{ unContextStack :: NonEmpty (Context, Captures) }
   deriving (Show)
 
 data TokenizerState = TokenizerState{
@@ -48,11 +52,10 @@ data TokenizerState = TokenizerState{
   , endline             :: Bool
   , prevChar            :: Char
   , contextStack        :: ContextStack
-  , captures            :: IntMap.IntMap ByteString
+  , captures            :: Captures
   , column              :: Int
   , lineContinuation    :: Bool
   , firstNonspaceColumn :: Maybe Int
-  , compiledRegexes     :: Map.Map RE Regex
 }
 
 -- | Configuration options for 'tokenize'.
@@ -68,9 +71,9 @@ data Result e a = Success a
 
 deriving instance (Show a, Show e) => Show (Result e a)
 
-data TokenizerM a = TM { runTokenizerM :: TokenizerConfig
-                                       -> TokenizerState
-                                       -> (TokenizerState, Result String a) }
+newtype TokenizerM a = TM { runTokenizerM :: TokenizerConfig
+                                          -> TokenizerState
+                                          -> (TokenizerState, Result String a) }
 
 mapsnd :: (a -> b) -> (c, a) -> (c, b)
 mapsnd f (x, y) = (x, f y)
@@ -121,7 +124,7 @@ instance MonadPlus TokenizerM where
 
 instance MonadReader TokenizerConfig TokenizerM where
   ask = TM (\c s -> (s, Success c))
-  local f (TM x) = TM (\c s -> x (f c) s)
+  local f (TM x) = TM (x . f)
 
 instance MonadState TokenizerState TokenizerM where
   get = TM (\_ s -> (s, Success s))
@@ -148,18 +151,17 @@ tokenize config syntax inp =
     action = mapM tokenizeLine (zip (BS.lines (encodeUtf8 inp)) [1..])
     eitherStack = case lookupContext (sStartingContext syntax)
                          (resolveKeywords (syntaxMap config) syntax) of
-                    Just c  -> Right $ ContextStack (c :| [])
+                    Just c  -> Right $ ContextStack ((c, Captures mempty) :| [])
                     Nothing -> Left "No starting context specified"
     startingState stack =
       TokenizerState{ input = BS.empty
                     , endline = Text.null inp
                     , prevChar = '\n'
                     , contextStack = stack
-                    , captures = mempty
+                    , captures = Captures mempty
                     , column = 0
                     , lineContinuation = False
                     , firstNonspaceColumn = Nothing
-                    , compiledRegexes = Map.empty
                     }
 
 info :: String -> TokenizerM ()
@@ -172,7 +174,7 @@ infoContextStack = do
   tr <- asks traceOutput
   when tr $ do
     ContextStack stack <- gets contextStack
-    info $ "CONTEXT STACK " ++ show (map cName $ toList stack)
+    info $ "CONTEXT STACK " ++ show (map (cName . fst) $ toList stack)
 
 popContextStack :: TokenizerM ()
 popContextStack = do
@@ -187,12 +189,13 @@ pushContextStack :: Context -> TokenizerM ()
 pushContextStack cont = do
   modify (\st -> st{ contextStack =
                       ContextStack
-                       ((cont <|) . unContextStack $ contextStack st) } )
+                       (((cont, Captures mempty) <|) . unContextStack
+                         $ contextStack st) } )
   infoContextStack
 
 currentContext :: TokenizerM Context
 currentContext = do
-  ContextStack (c :| _) <- gets contextStack
+  ContextStack ((c,_) :| _) <- gets contextStack
   return c
 
 doContextSwitch :: ContextSwitch -> TokenizerM ()
@@ -206,6 +209,28 @@ doContextSwitch (Push (!syn,!c)) = do
 doContextSwitches :: [ContextSwitch] -> TokenizerM ()
 doContextSwitches = mapM_ doContextSwitch
 
+addCaptures :: TokenizerM ()
+addCaptures = do
+  capts <- gets captures
+  if IntMap.null (unCaptures capts)
+     then return ()
+     else do
+       ContextStack ((c,_) :| cs) <- gets contextStack
+       info $ "Adding captures to " <> show (cName c) <> ": " <> show capts
+       modify $ \st -> st{ contextStack = ContextStack ((c,capts) :| cs) }
+
+getCapture :: Int -> TokenizerM Text
+getCapture capnum = do
+  ContextStack ((_,Captures capts) :| _) <- gets contextStack
+  info $ "Retrieving capture " <> show capnum
+  res <- case IntMap.lookup capnum capts of
+          Nothing -> do
+            info "Not found"
+            mzero
+          Just x  -> decodeBS x
+  info $ "Got " <> show res
+  return res
+
 lookupContext :: Text -> Syntax -> Maybe Context
 lookupContext name syntax | Text.null name =
   if Text.null (sStartingContext syntax)
@@ -284,6 +309,9 @@ tryRule rule inp = do
                  then Just <$> get -- needed for lookahead rules
                  else return Nothing
 
+  -- reset regex captures
+  modify $ \st -> st{ captures = Captures mempty }
+
   let attr = rAttribute rule
   mbtok <- case rMatcher rule of
                 DetectChar c -> withAttr attr $ detectChar (rDynamic rule) c inp
@@ -340,8 +368,11 @@ tryRule rule inp = do
 
   info $ takeWhile (/=' ') (show (rMatcher rule)) ++ " MATCHED " ++ show mbtok'
   doContextSwitches (rContextSwitch rule)
+  -- Add any captures to the context on top of the stack
+  addCaptures
   return mbtok'
 
+
 withAttr :: TokenType -> TokenizerM Text -> TokenizerM (Maybe Token)
 withAttr tt p = do
   res <- p
@@ -424,6 +455,7 @@ includeRules mbattr (syn, con) inp = do
            Text.unpack con ++ "##" ++ Text.unpack syn
        Just c   -> do
          mbtok <- msum (map (\r -> tryRule r inp) (cRules c))
+         modify $ \st -> st{ captures = Captures mempty }
          return $ case (mbtok, mbattr) of
                     (Just (NormalTok, xs), Just attr) -> Just (attr, xs)
                     _                                 -> mbtok
@@ -518,25 +550,18 @@ regExpr dynamic re inp = do
   -- return $! traceShowId $! (reStr, inp)
   let reStr = reString re
   when (BS.take 2 reStr == "\\b") $ wordBoundary inp
-  compiledREs <- gets compiledRegexes
-  regex <- case Map.lookup re compiledREs of
-              Nothing -> do
-                cre <- case compileRegex (reCaseSensitive re) reStr of
-                         Right r  -> return r
-                         Left e   -> throwError $
-                           "Error compiling regex " ++
-                            UTF8.toString reStr ++ ": " ++ e
-                modify $ \st -> st{ compiledRegexes =
-                      Map.insert re cre (compiledRegexes st) }
-                return cre
-              Just cre -> return cre
+  regex <- case compileRE re of
+            Right r  -> return r
+            Left e   -> throwError $
+              "Error compiling regex " ++
+              UTF8.toString reStr ++ ": " ++ e
   regex' <- if dynamic
                then subDynamic regex
                else return regex
   case matchRegex regex' inp of
         Just (matchedBytes, capts) -> do
           unless (null capts) $
-             modify $ \st -> st{ captures =
+            modify $ \st -> st{ captures = Captures $
                                   IntMap.map (toSlice inp) capts }
           takeChars (UTF8.length matchedBytes)
         _ -> mzero
@@ -581,13 +606,6 @@ subDynamic (AssertNegative dir r) =
   AssertNegative dir <$> subDynamic r
 subDynamic x = return x
 
-getCapture :: Int -> TokenizerM Text
-getCapture capnum = do
-  capts <- gets captures
-  case IntMap.lookup capnum capts of
-     Nothing -> throwError $ "Capture " <> show capnum <> " not defined!"
-     Just x  -> decodeBS x
-
 keyword :: KeywordAttr -> WordSet Text -> ByteString -> TokenizerM Text
 keyword kwattr kws inp = do
   prev <- gets prevChar
@@ -648,8 +666,7 @@ parseInt inp = do
 pDec :: A.Parser ()
 pDec = do
   mbMinus
-  _ <- A.takeWhile1 (A.inClass "0-9")
-  guardWordBoundary
+  void $ A.takeWhile1 (A.inClass "0-9")
 
 parseOct :: ByteString -> TokenizerM Text
 parseOct inp = do
@@ -664,7 +681,7 @@ pOct = do
   _ <- A.char '0'
   _ <- A.satisfy (A.inClass "Oo")
   _ <- A.takeWhile1 (A.inClass "0-7")
-  guardWordBoundary
+  return ()
 
 parseHex :: ByteString -> TokenizerM Text
 parseHex inp = do
@@ -679,14 +696,7 @@ pHex = do
   _ <- A.char '0'
   _ <- A.satisfy (A.inClass "Xx")
   _ <- A.takeWhile1 (A.inClass "0-9a-fA-F")
-  guardWordBoundary
-
-guardWordBoundary :: A.Parser ()
-guardWordBoundary = do
-  mbw <- A.peekChar
-  case mbw of
-       Just c  ->  guard $ isWordBoundary '0' c
-       Nothing -> return ()
+  return ()
 
 mbMinus :: A.Parser ()
 mbMinus = (() <$ A.char '-') <|> return ()
